==> drd-8.x-3.5.tar.gz: drd/src/Crypt/BaseMethodInterface.php <==
<?php

namespace Drupal\drd\Crypt;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides an interface for encryption methods.
 *
 * @ingroup drd
 */
interface BaseMethodInterface {

  /**
   * Can be overwritten and determines if the CryptMethod works with a password.
   *
   * @return bool
   */
  public function requiresPassword();

  /**
   * @return BaseMethodInterface
   */
  public function resetPassword();

  /**
   * @return array
   */
  public function getSettings();

  /**
   * @return string
   */
  public function getLabel();

  /**
   * @return bool
   */
  public function isAvailable();

  /**
   * @return array
   */
  public function getCipherMethods();

  /**
   * @param array $form
   * @param array $condition
   */
  public function settingsForm(array &$form, array $condition);

  /**
   * @param FormStateInterface $form_state
   * @return array
   */
  public function settingsFormValues(FormStateInterface $form_state);

  /**
   * @return string
   */
  public function getIV();

  /**
   * @return string
   */
  public function getCipher();

  /**
   * @return string
   */
  public function getPassword();

  /**
   * @param array $args
   * @return string
   */
  public function encrypt($args);

  /**
   * @param string $body
   * @param string $iv
   * @return array
   */
  public function decrypt($body, $iv);

  /**
   * @param string $filename
   *
   * @return string
   */
  public function encryptFile($filename);

  /**
   * @param string $filename
   *
   * @return string
   */
  public function decryptFile($filename);

}

==> drd-8.x-3.10.tar.gz: drd/src/Crypt/BaseMethodInterface.php <==
<?php

namespace Drupal\drd\Crypt;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides an interface for encryption methods.
 *
 * @ingroup drd
 */
interface BaseMethodInterface {

  /**
   * Can be overwritten and determines if the CryptMethod works with a password.
   *
   * @return bool
   */
  public function requiresPassword();

  /**
   * @return $this
   */
  public function resetPassword();

  /**
   * @return array
   */
  public function getSettings();

  /**
   * @return string
   */
  public function getLabel();

  /**
   * @return bool
   */
  public function isAvailable();

  /**
   * @return array
   */
  public function getCipherMethods();

  /**
   * @param array $form
   * @param array $condition
   */
  public function settingsForm(array &$form, array $condition);

  /**
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   * @return array
   */
  public function settingsFormValues(FormStateInterface $form_state);

  /**
   * @return string
   */
  public function getIV();

  /**
   * @return string
   */
  public function getCipher();

  /**
   * @return string
   */
  public function getPassword();

  /**
   * @param array $args
   * @return string
   */
  public function encrypt($args);

  /**
   * @param string $body
   * @param string $iv
   * @return array
   */
  public function decrypt($body, $iv);

  /**
   * @param string $filename
   *
   * @return string
   */
  public function encryptFile($filename);

  /**
   * @param string $filename
   *
   * @return string
   */
  public function decryptFile($filename);

}
